summaryrefslogtreecommitdiffstats
path: root/quanta/dialogs/settings/parseroptions.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit6c79d50fa9fbdff7f69ca57a8ab5fcc942375593 (patch)
treef47737d56c3239a0d8bc600674f0ca04b6e30d6e /quanta/dialogs/settings/parseroptions.cpp
parent36c36b53a129509d56fdaa0a7c9fcbcacd0c5826 (diff)
downloadtdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.tar.gz
tdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'quanta/dialogs/settings/parseroptions.cpp')
-rw-r--r--quanta/dialogs/settings/parseroptions.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/quanta/dialogs/settings/parseroptions.cpp b/quanta/dialogs/settings/parseroptions.cpp
index c38e2875..f3fad631 100644
--- a/quanta/dialogs/settings/parseroptions.cpp
+++ b/quanta/dialogs/settings/parseroptions.cpp
@@ -22,11 +22,11 @@
#include <kconfig.h>
/*
* Constructs a ParserOptions which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/
-ParserOptions::ParserOptions( KConfig *a_config, TQWidget* tqparent, const char* name )
- : ParserOptionsUI( tqparent, name )
+ParserOptions::ParserOptions( KConfig *a_config, TQWidget* parent, const char* name )
+ : ParserOptionsUI( parent, name )
{
config = a_config;
config->setGroup("Parser options");
@@ -22,11 +22,11 @@
#include <kconfig.h>
/*
- * Constructs a ParserOptions which is a child of 'tqparent', with the
+ * Constructs a ParserOptions which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/